@@ -75,32 +75,43 @@ struct _IndicateIndicator {
 #include "server.h"
 
 /**
-	IndicateIndicatorClass:
-	@parent_class: Parent class #GObjectClass.
-	@hide: Slot for #IndicateIndicator::hide.
-	@show: Slot for #IndicateIndicator::show.
-	@user_display: Slot for #IndicateIndicator::user-display.
-	@modified: Slot for #IndicateIndicator::modified.
-	@displayed: Slot for #IndicateIndicator::displayed.
-	@set_property: Called when indicate_indicator_set_property() is called
-		and should set the value.  While typically it is overridden by
-		subclasses they usually handle special properties themselves and
-		then call the superclass for storage.
-	@get_property: Called when indicate_indicator_get_property() is called
-		and should return the value requested.  Many times this is left alone.
-	@list_properties: Called when indicate_indicator_list_properties() is called
-		and returns a list of the properties available.  Again this can be
-		overridden by subclasses to handle special properties.
-	@indicate_indicator_reserved1: Reserved for future use
-	@indicate_indicator_reserved2: Reserved for future use
-	@indicate_indicator_reserved3: Reserved for future use
-	@indicate_indicator_reserved4: Reserved for future use
+ * indicate_indicator_list_properties_slot_t:
+ * @indicator: (in): Indicator to get the properties from
+ *
+ * Prototype for a function that will list all the properies in
+ * an indicator.
+ *
+ * Return value: (transfer full) (array) (element-type utf8):
+ *   The names of the properties that are in this indicator.
+ */
+typedef GPtrArray * (*indicate_indicator_list_properties_slot_t) (IndicateIndicator * indicator);
 
-	All of the functions that are used to modify or change data that is
-	in the indicator.  Typically gets subclassed by other types of 
-	indicators, for example #IndicateIndicatorMessages.
-
-*/
+/**
+ * IndicateIndicatorClass:
+ * @parent_class: Parent class #GObjectClass.
+ * @hide: Slot for #IndicateIndicator::hide.
+ * @show: Slot for #IndicateIndicator::show.
+ * @user_display: Slot for #IndicateIndicator::user-display.
+ * @modified: Slot for #IndicateIndicator::modified.
+ * @displayed: Slot for #IndicateIndicator::displayed.
+ * @set_property: Called when indicate_indicator_set_property() is called
+ *   and should set the value.  While typically it is overridden by
+ *   subclasses they usually handle special properties themselves and
+ *   then call the superclass for storage.
+ * @get_property: Called when indicate_indicator_get_property() is called
+ *   and should return the value requested.  Many times this is left alone.
+ * @list_properties: Called when indicate_indicator_list_properties() is called
+ *   and returns a list of the properties available.  Again this can be
+ *   overridden by subclasses to handle special properties.
+ * @indicate_indicator_reserved1: Reserved for future use
+ * @indicate_indicator_reserved2: Reserved for future use
+ * @indicate_indicator_reserved3: Reserved for future use
+ * @indicate_indicator_reserved4: Reserved for future use
+ *
+ * All of the functions that are used to modify or change data that is
+ * in the indicator.  Typically gets subclassed by other types of 
+ * indicators, for example #IndicateIndicatorMessages.
+ */
 struct _IndicateIndicatorClass {
 	/* Parents */
 	GObjectClass parent_class;
@@ -115,7 +126,7 @@ struct _IndicateIndicatorClass {
 	/* Subclassable functions */
 	void (*set_property) (IndicateIndicator * indicator, const gchar * key, const GValue * data);
 	const GValue * (*get_property) (IndicateIndicator * indicator, const gchar * key);
-	GPtrArray * (*list_properties) (IndicateIndicator * indicator);
+	indicate_indicator_list_properties_slot_t list_properties;
 
 	/* Reserver for future use */
 	void (*indicate_indicator_reserved1)(void);
@@ -155,6 +166,16 @@ void indicate_indicator_set_property_value (IndicateIndicator * indicator, const
 const gchar * indicate_indicator_get_property (IndicateIndicator * indicator, const gchar * key);
 const GValue * indicate_indicator_get_property_value (IndicateIndicator * indicator, const gchar * key);
 
+/**
+ * indicate_indicator_list_properties:
+ * @indicator: (in): a #IndicateIndicator to act on
+ *
+ * This function gets a list of all the properties that exist
+ * on a @indicator.  The array may have zero entries.
+ *
+ * Return value: (transfer full) (array) (element-type utf8): An array of
+ *   strings that is the keys of all the properties on this indicator.
+ */
 GPtrArray * indicate_indicator_list_properties (IndicateIndicator * indicator);
 
 /* Controling whether it's displayed */
